@@ -1,13 +1,14 @@
 use strict;
 use warnings;
 
-package Sub::Prototype;
+package Sub::Prototype; # git description: 0.02-3-gb5d237a
+# ABSTRACT: Set a sub's prototype
 
 require 5.008001;
 
 use XSLoader;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 XSLoader::load(__PACKAGE__, $VERSION);
 
@@ -20,9 +21,17 @@ use Sub::Exporter -setup => {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Sub::Prototype - Set a subs prototype
+Sub::Prototype - Set a sub's prototype
+
+=head1 VERSION
+
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -50,16 +59,26 @@ Sets the prototype for C<coderef> to C<$prototype>.
 
 Shawn M Moore for the idea and tests.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Sub-Prototype>
+(or L<bug-Sub-Prototype@rt.cpan.org|mailto:bug-Sub-Prototype@rt.cpan.org>).
+
 =head1 AUTHOR
 
-Florian Ragwitz E<lt>rafl@debian.orgE<gt>
+Florian Ragwitz <rafl@debian.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTOR
 
-Copyright (c) 2008  Florian Ragwitz
+=for stopwords Karen Etheridge
 
-This module is free software.
+Karen Etheridge <ether@cpan.org>
 
-It may distribute it under the same terms as perl itself.
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Florian Ragwitz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
